@@ -38,7 +38,14 @@
 #include <QThread>
 #include <QProcessEnvironment>
 #include <QTimer>
+#include <QRegularExpression>
+#if defined(Q_OS_LINUX)
 #include <pty.h>
+#else
+#include <errno.h>
+#include <termios.h>
+#include <util.h>
+#endif
 #include <unistd.h>
 #include <memory>
 #include <csignal>
@@ -46,6 +53,7 @@
 #include <fcntl.h>
 #include <iostream>
 #include <thread>
+#include <sstream>
 
 namespace
 {
@@ -89,7 +97,7 @@ namespace
         "DISPLAY"
             , "LANG", "LANGUAGE", "LC_ADDRESS", "LC_ALL", "LC_COLLATE", "LC_CTYPE", "LC_IDENTIFICATION", "LC_MEASUREMENT"
             , "LC_MESSAGES", "LC_MONETARY", "LC_NAME", "LC_NUMERIC", "LC_PAPER", "LC_TELEPHONE", "LC_TIME"
-            , "PATH", "QT_PLATFORM_PLUGIN", "QT_QPA_PLATFORMTHEME", "WAYLAND_DISPLAY", "XAUTHLOCALHOSTNAME", "XAUTHORITY"
+            , "PATH", "QT_PLATFORM_PLUGIN", "QT_QPA_PLATFORMTHEME", "TERM", "WAYLAND_DISPLAY", "XAUTHLOCALHOSTNAME", "XAUTHORITY"
     };
     static constexpr char const * const * const ALLOWED_END = ALLOWED_VARS + sizeof (ALLOWED_VARS) / sizeof (ALLOWED_VARS[0]);
     struct assert_helper
@@ -102,24 +110,27 @@ namespace
     };
     assert_helper h;
 
-    inline void env_workarounds()
+    inline std::string env_workarounds()
     {
         std::cerr << LXQTSUDO << ": Stripping child environment except for: ";
-        std::copy(ALLOWED_VARS, ALLOWED_END - 1, std::ostream_iterator<const char *>{std::cerr, ", "});
-        std::cerr << *(ALLOWED_END - 1) << '\n'; // printing the last separately to avoid trailing comma
+        std::ostringstream left_env_params;
+        std::copy(ALLOWED_VARS, ALLOWED_END - 1, std::ostream_iterator<const char *>{left_env_params, ","});
+        left_env_params << *(ALLOWED_END - 1); // printing the last separately to avoid trailing comma
+        std::cerr << left_env_params.str() << '\n';
         // cleanup environment, because e.g.:
         // - pcmanfm-qt will not start if the DBUS_SESSION_BUS_ADDRESS is preserved
         // - Qt apps may change user's config files permissions if the XDG_* are preserved
         for (auto const & key : QProcessEnvironment::systemEnvironment().keys())
         {
             auto const & i = std::lower_bound(ALLOWED_VARS, ALLOWED_END, key, [] (char const * const a, QString const & b) {
-                return b > a;
-            });
-            if (i == ALLOWED_END || key != *i)
+                    return b > QLatin1String(a);
+                    });
+            if (i == ALLOWED_END || key != QLatin1String(*i))
             {
                 unsetenv(key.toLatin1().data());
             }
         }
+        return left_env_params.str();
     }
 
     inline QString quoteShellArg(const QString& arg, bool userFriendly)
@@ -127,9 +138,9 @@ namespace
         QString rv = arg;
 
         //^ check if thre are any bash special file characters
-        if (!userFriendly || arg.contains(QRegExp("(\\s|[][!\"#$&'()*,;<=>?\\^`{}|~])"))) {
+        if (!userFriendly || arg.contains(QRegularExpression(QStringLiteral("(\\s|[][!\"#$&'()*,;<=>?\\^`{}|~])")))) {
             rv.replace(QStringLiteral("'"), QStringLiteral("'\\''"));
-            rv.prepend ('\'').append('\'');
+            rv.prepend (QLatin1Char('\'')).append(QLatin1Char('\''));
         }
 
         return rv;
@@ -146,6 +157,7 @@ Sudo::Sudo()
         mBackend = BACK_SU;
     else if (app_lxsudo == cmd || app_master == cmd)
         mBackend = BACK_SUDO;
+    mRet = mPwdFd = mChildPid = 0;
 }
 
 Sudo::~Sudo()
@@ -158,19 +170,19 @@ int Sudo::main()
     {
         //simple option check
         QString const & arg1 = mArgs[0];
-        if ("-h" == arg1 || "--help" == arg1)
+        if (QStringLiteral("-h") == arg1 || QStringLiteral("--help") == arg1)
         {
             usage();
             return 0;
-        } else if ("-v" == arg1 || "--version" == arg1)
+        } else if (QStringLiteral("-v") == arg1 || QStringLiteral("--version") == arg1)
         {
             version();
             return 0;
-        } else if ("-s" == arg1 || "--su" == arg1)
+        } else if (QStringLiteral("-s") == arg1 || QStringLiteral("--su") == arg1)
         {
             mBackend = BACK_SU;
             mArgs.removeAt(0);
-        } else if ("-d" == arg1 || "--sudo" == arg1)
+        } else if (QStringLiteral("-d") == arg1 || QStringLiteral("--sudo") == arg1)
         {
             mBackend = BACK_SUDO;
             mArgs.removeAt(0);
@@ -204,7 +216,7 @@ int Sudo::main()
 
     if (-1 == mChildPid)
         QMessageBox(QMessageBox::Critical, mDlg->windowTitle()
-                , tr("Syscall error, failed to fork: %1").arg(strerror(errno)), QMessageBox::Ok).exec();
+                , tr("Syscall error, failed to fork: %1").arg(QString::fromUtf8(strerror(errno))), QMessageBox::Ok).exec();
     else
         return parent();
 
@@ -217,7 +229,7 @@ QString Sudo::squashedArgs(bool userFriendly) const
 
     rv = quoteShellArg (mArgs[0], userFriendly);
     for (auto argP = ++mArgs.begin(); argP != mArgs.end(); ++argP) {
-        rv.append (' ').append(quoteShellArg (*argP, userFriendly));
+        rv.append (QLatin1Char(' ')).append(quoteShellArg (*argP, userFriendly));
     }
 
     return rv;
@@ -245,10 +257,23 @@ void Sudo::child()
     const char ** param_arg = params.get() + 1;
 
     std::string program = backendName().toLocal8Bit().data();
-    if (BACK_SUDO == mBackend)
+
+    std::string preserve_env_param;
+    switch (mBackend)
     {
-        *(param_arg++) = "-E"; //preserve environment
-        *(param_arg++) = "/bin/sh";
+        case BACK_SUDO:
+            preserve_env_param = "--preserve-env=";
+
+            preserve_env_param += env_workarounds();
+
+            *(param_arg++) = preserve_env_param.c_str(); //preserve environment
+            *(param_arg++) = "/bin/sh";
+            break;
+        case BACK_SU:
+        case BACK_NONE:
+            env_workarounds();
+            break;
+
     }
     *(param_arg++) = "-c"; //run command
 
@@ -267,7 +292,7 @@ void Sudo::child()
         // for privileged execution via the LC_ALL
         if (nullptr != strchr(env_lc_all, '\''))
         {
-            QTextStream{stderr, QIODevice::WriteOnly} << tr("%1: Detected attempt to inject privileged command via LC_ALL env(%2). Exiting!\n").arg(app_master).arg(env_lc_all);
+            QTextStream{stderr, QIODevice::WriteOnly} << tr("%1: Detected attempt to inject privileged command via LC_ALL env(%2). Exiting!\n").arg(app_master).arg(QString::fromUtf8(env_lc_all));
             exit(1);
         }
         command = "LC_ALL='";
@@ -282,13 +307,11 @@ void Sudo::child()
 
     setenv("LC_ALL", "C", 1);
 
-    env_workarounds();
-
     setsid(); //session leader
     execvp(params[0], const_cast<char **>(params.get()));
 
     //exec never returns in case of success
-    QTextStream{stderr, QIODevice::WriteOnly} << tr("%1: Failed to exec '%2': %3\n").arg(app_master).arg(params[0]).arg(strerror(errno));
+    QTextStream{stderr, QIODevice::WriteOnly} << tr("%1: Failed to exec '%2': %3\n").arg(app_master).arg(QString::fromUtf8(params[0])).arg(QString::fromUtf8(strerror(errno)));
     exit(1);
 }
 
@@ -311,7 +334,7 @@ int Sudo::parent()
     if (0 != fcntl(mPwdFd, F_SETFL, O_NONBLOCK))
     {
         QMessageBox(QMessageBox::Critical, mDlg->windowTitle()
-                , tr("Syscall error, failed to bring pty to non-block mode: %1").arg(strerror(errno)), QMessageBox::Ok).exec();
+                , tr("Syscall error, failed to bring pty to non-block mode: %1").arg(QString::fromUtf8(strerror(errno))), QMessageBox::Ok).exec();
         return 1;
     }
 
@@ -319,7 +342,7 @@ int Sudo::parent()
     if (nullptr == pwd_f)
     {
         QMessageBox(QMessageBox::Critical, mDlg->windowTitle()
-                , tr("Syscall error, failed to fdopen pty: %1").arg(strerror(errno)), QMessageBox::Ok).exec();
+                , tr("Syscall error, failed to fdopen pty: %1").arg(QString::fromUtf8(strerror(errno))), QMessageBox::Ok).exec();
         return 1;
     }
 
