@@ -5,55 +5,46 @@
     <name>PasswordDialog</name>
     <message>
         <location filename="../passworddialog.ui" line="6"/>
-        <location filename="../obj-x86_64-linux-gnu/lxqt-sudo_autogen/include/ui_passworddialog.h" line="171"/>
         <source>LXQt sudo</source>
         <translation></translation>
     </message>
     <message>
         <location filename="../passworddialog.ui" line="42"/>
-        <location filename="../obj-x86_64-linux-gnu/lxqt-sudo_autogen/include/ui_passworddialog.h" line="173"/>
         <source>Copy command to clipboard</source>
         <translation>העתקת הפקודה ללוח הגזירים</translation>
     </message>
     <message>
         <location filename="../passworddialog.ui" line="45"/>
-        <location filename="../obj-x86_64-linux-gnu/lxqt-sudo_autogen/include/ui_passworddialog.h" line="175"/>
         <source>&amp;Copy</source>
         <translation>ה&amp;עתקה</translation>
     </message>
     <message>
         <location filename="../passworddialog.ui" line="83"/>
-        <location filename="../obj-x86_64-linux-gnu/lxqt-sudo_autogen/include/ui_passworddialog.h" line="176"/>
         <source>The requested action needs administrative privileges.&lt;br&gt;Please enter your password.</source>
         <translation>הפעולה המבוקשת דורשת הרשאות ניהול.&lt;br&gt;נא להקליד ססמה.</translation>
     </message>
     <message>
         <location filename="../passworddialog.ui" line="106"/>
-        <location filename="../obj-x86_64-linux-gnu/lxqt-sudo_autogen/include/ui_passworddialog.h" line="178"/>
         <source>LXQt sudo backend</source>
         <translation>מנגנון LXQt sudo</translation>
     </message>
     <message>
         <location filename="../passworddialog.ui" line="109"/>
-        <location filename="../obj-x86_64-linux-gnu/lxqt-sudo_autogen/include/ui_passworddialog.h" line="181"/>
         <source>A program LXQt sudo calls in background to elevate privileges.</source>
         <translation>התכנית LXQt sudo קוראת ברקע כדי להעלות את רמת ההרשאה.</translation>
     </message>
     <message>
         <location filename="../passworddialog.ui" line="119"/>
-        <location filename="../obj-x86_64-linux-gnu/lxqt-sudo_autogen/include/ui_passworddialog.h" line="183"/>
         <source>Command:</source>
         <translation>פקודה:</translation>
     </message>
     <message>
         <location filename="../passworddialog.ui" line="126"/>
-        <location filename="../obj-x86_64-linux-gnu/lxqt-sudo_autogen/include/ui_passworddialog.h" line="184"/>
         <source>Password:</source>
         <translation>ססמה:</translation>
     </message>
     <message>
         <location filename="../passworddialog.ui" line="133"/>
-        <location filename="../obj-x86_64-linux-gnu/lxqt-sudo_autogen/include/ui_passworddialog.h" line="186"/>
         <source>Enter password</source>
         <translation>נא להקליד ססמה</translation>
     </message>
@@ -66,7 +57,7 @@
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../sudo.cpp" line="69"/>
+        <location filename="../sudo.cpp" line="75"/>
         <source>Usage: %1 option [command [arguments...]]
 
 GUI frontend for %2/%3
@@ -81,10 +72,23 @@ Arguments:
   arguments        Optional arguments for command.
 
 </source>
-        <translation></translation>
+        <translation>שימוש: %1 option [command [arguments...]]
+
+GUI frontend for %2/%3
+
+Arguments:
+  אפשרויות:
+    -h|--help      Print this help.
+    -v|--version   הדפסת מידע הגרסה.
+    -s|--su        שימוש ב־%3(1) כמגשר עורפי.
+    -d|--sudo      שימוש ב־%2(8) כמגשר עורפי.
+  command          פקודה להרצה.
+  arguments        Optional arguments for command.
+
+</translation>
     </message>
     <message>
-        <location filename="../sudo.cpp" line="86"/>
+        <location filename="../sudo.cpp" line="92"/>
         <source>%1 version %2
 </source>
         <translation></translation>
@@ -93,51 +97,51 @@ Arguments:
 <context>
     <name>Sudo</name>
     <message>
-        <location filename="../sudo.cpp" line="189"/>
+        <location filename="../sudo.cpp" line="195"/>
         <source>%1: no command to run provided!</source>
-        <translation></translation>
+        <translation>%1: לא סופקה פקודה להרצה!</translation>
     </message>
     <message>
-        <location filename="../sudo.cpp" line="196"/>
+        <location filename="../sudo.cpp" line="202"/>
         <source>%1: no backend chosen!</source>
-        <translation></translation>
+        <translation>%1: לא נבחר מגשר עורפי!</translation>
     </message>
     <message>
-        <location filename="../sudo.cpp" line="213"/>
+        <location filename="../sudo.cpp" line="219"/>
         <source>Syscall error, failed to fork: %1</source>
         <translation>שגיאת קריאת מערכת, הפיצול נכשל: %1</translation>
     </message>
     <message>
-        <location filename="../sudo.cpp" line="240"/>
+        <location filename="../sudo.cpp" line="246"/>
         <source>unset</source>
         <extracomment>shouldn&apos;t be actually used but keep as short as possible in translations just in case.</extracomment>
         <translation>לא הוגדר</translation>
     </message>
     <message>
-        <location filename="../sudo.cpp" line="289"/>
+        <location filename="../sudo.cpp" line="295"/>
         <source>%1: Detected attempt to inject privileged command via LC_ALL env(%2). Exiting!
 </source>
         <translation>%1: התגלה ניסיון להזריק פקודה עם הרשאות על דרך משתנה הסביבה LC_ALL ‏(%2). התכנית תיסגר!
 </translation>
     </message>
     <message>
-        <location filename="../sudo.cpp" line="331"/>
+        <location filename="../sudo.cpp" line="337"/>
         <source>Syscall error, failed to bring pty to non-block mode: %1</source>
         <translation>שגיאת קריאת מערכת, הבאת ה־pty למצב נוגד חסימות נכשל: %1</translation>
     </message>
     <message>
-        <location filename="../sudo.cpp" line="339"/>
+        <location filename="../sudo.cpp" line="345"/>
         <source>Syscall error, failed to fdopen pty: %1</source>
         <translation>שגיאת קריאת מערכת, הפעלת fdopen על pty נכשלה: %1</translation>
     </message>
     <message>
-        <location filename="../sudo.cpp" line="308"/>
+        <location filename="../sudo.cpp" line="314"/>
         <source>%1: Failed to exec &apos;%2&apos;: %3
 </source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../sudo.cpp" line="370"/>
+        <location filename="../sudo.cpp" line="376"/>
         <source>Child &apos;%1&apos; process failed!
 %2</source>
         <translation></translation>
